# Drv Can

Repository that storages classes and functions used create a thread that can send,
and receive can messages. The node class will create a thread with a shared object
that receives the commands both for the can module and also the messages to send through can bus.
The commands that can be send to can are create and remove filter, and also send messages.

